pub struct UserFlags(/* private fields */);Implementations
Sourceimpl UserFlags
impl UserFlags
Sourcepub const BUG_HUNTER_LEVEL_1: Self
pub const BUG_HUNTER_LEVEL_1: Self
Bug hunter level 1.
Sourcepub const HYPESQUAD_ONLINE_HOUSE_1: Self
pub const HYPESQUAD_ONLINE_HOUSE_1: Self
House Bravery member.
Sourcepub const HYPESQUAD_ONLINE_HOUSE_2: Self
pub const HYPESQUAD_ONLINE_HOUSE_2: Self
House Brilliance member.
Sourcepub const HYPESQUAD_ONLINE_HOUSE_3: Self
pub const HYPESQUAD_ONLINE_HOUSE_3: Self
House Balance member.
Sourcepub const PREMIUM_EARLY_SUPPORTER: Self
pub const PREMIUM_EARLY_SUPPORTER: Self
Early Nitro supporter.
Sourcepub const TEAM_PSEUDO_USER: Self
pub const TEAM_PSEUDO_USER: Self
User is in a team.
Sourcepub const BUG_HUNTER_LEVEL_2: Self
pub const BUG_HUNTER_LEVEL_2: Self
Bug hunter level 2.
Sourcepub const VERIFIED_BOT: Self
pub const VERIFIED_BOT: Self
Verified bot.
Sourcepub const VERIFIED_DEVELOPER: Self
pub const VERIFIED_DEVELOPER: Self
Early verified bot developer.
Sourcepub const MODERATOR_PROGRAMS_ALUMNI: Self
pub const MODERATOR_PROGRAMS_ALUMNI: Self
Moderator Programs Alumni
Sourcepub const BOT_HTTP_INTERACTIONS: Self
pub const BOT_HTTP_INTERACTIONS: Self
Bot uses only HTTP interactions and is shown in the online member list.
Sourcepub const ACTIVE_DEVELOPER: Self
pub const ACTIVE_DEVELOPER: Self
User is an Active Developer.
Sourceimpl UserFlags
impl UserFlags
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl UserFlags
impl UserFlags
Sourcepub const fn iter(&self) -> Iter<UserFlags>
pub const fn iter(&self) -> Iter<UserFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<UserFlags>
pub const fn iter_names(&self) -> IterNames<UserFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.